@@ -8,7 +8,7 @@ package Excel::Writer::XLSX::Chart::Bar;
 #
 # See formatting note in Excel::Writer::XLSX::Chart.
 #
-# Copyright 2000-2012, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2013, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.64';
+our $VERSION = '0.66';
 
 
 ###############################################################################
@@ -110,6 +110,13 @@ sub _write_bar_chart {
     my $subtype = $self->{_subtype};
     $subtype = 'percentStacked' if $subtype eq 'percent_stacked';
 
+    # Set a default overlap for stacked charts.
+    if ($self->{_subtype} =~ /stacked/) {
+        if (!defined $self->{_series_overlap}) {
+            $self->{_series_overlap} = 100;
+        }
+    }
+
     $self->xml_start_tag( 'c:barChart' );
 
     # Write the c:barDir element.
@@ -124,8 +131,11 @@ sub _write_bar_chart {
     # Write the c:marker element.
     $self->_write_marker_value();
 
+    # Write the c:gapWidth element.
+    $self->_write_gap_width( $self->{_series_gap} );
+
     # Write the c:overlap element.
-    $self->_write_overlap() if $self->{_subtype} =~ /stacked/;
+    $self->_write_overlap( $self->{_series_overlap} );
 
     # Write the c:axId elements
     $self->_write_axis_ids( %args );
@@ -300,7 +310,7 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright MM-MMXII, John McNamara.
+Copyright MM-MMXIII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
 
